@@ -99,7 +99,7 @@ gda_data_model_array_get_value_at (GdaDataModel *model, gint col, gint row)
 }
 
 static gboolean
-gda_data_model_array_is_editable (GdaDataModel *model)
+gda_data_model_array_is_updatable (GdaDataModel *model)
 {
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_ARRAY (model), FALSE);
 	return TRUE;
@@ -142,6 +142,56 @@ gda_data_model_array_remove_row (GdaDataModel *model, const GdaRow *row)
 	return FALSE;
 }
 
+static gboolean
+gda_data_model_array_update_row (GdaDataModel *model, const GdaRow *row)
+{
+	gint i;
+	GdaDataModelArrayPrivate *priv;
+
+	g_return_val_if_fail (GDA_IS_DATA_MODEL_ARRAY (model), FALSE);
+	g_return_val_if_fail (row != NULL, FALSE);
+
+	priv = GDA_DATA_MODEL_ARRAY (model)->priv;
+
+	for (i = 0; i < priv->rows->len; i++) {
+		if (priv->rows->pdata[i] == row) {
+			gda_row_free (priv->rows->pdata[i]);
+			priv->rows->pdata[i] = gda_row_copy ((GdaRow *) row);
+			gda_data_model_row_updated (model, i);
+
+			return TRUE;
+		}
+	}
+
+	return FALSE; /* row not found in this data model */
+}
+
+static gboolean
+gda_data_model_array_append_column (GdaDataModel *model, const GdaFieldAttributes *attrs)
+{
+	g_return_val_if_fail (GDA_IS_DATA_MODEL_ARRAY (model), FALSE);
+	g_return_val_if_fail (attrs != NULL, FALSE);
+
+	return FALSE;
+}
+
+static gboolean
+gda_data_model_array_update_column (GdaDataModel *model, gint col, const GdaFieldAttributes *attrs)
+{
+	g_return_val_if_fail (GDA_IS_DATA_MODEL_ARRAY (model), FALSE);
+	g_return_val_if_fail (attrs != NULL, FALSE);
+
+	return FALSE;
+}
+
+static gboolean
+gda_data_model_array_remove_column (GdaDataModel *model, gint col)
+{
+	g_return_val_if_fail (GDA_IS_DATA_MODEL_ARRAY (model), FALSE);
+
+	return FALSE;
+}
+
 static void
 gda_data_model_array_class_init (GdaDataModelArrayClass *klass)
 {
@@ -156,10 +206,13 @@ gda_data_model_array_class_init (GdaDataModelArrayClass *klass)
 	model_class->describe_column = gda_data_model_array_describe_column;
 	model_class->get_row = gda_data_model_array_get_row;
 	model_class->get_value_at = gda_data_model_array_get_value_at;
-	model_class->is_editable = gda_data_model_array_is_editable;
+	model_class->is_updatable = gda_data_model_array_is_updatable;
 	model_class->append_row = gda_data_model_array_append_row;
 	model_class->remove_row = gda_data_model_array_remove_row;
-	model_class->update_row = NULL;
+	model_class->update_row = gda_data_model_array_update_row;
+	model_class->append_column = gda_data_model_array_append_column;
+	model_class->update_column = gda_data_model_array_update_column;
+	model_class->remove_column = gda_data_model_array_remove_column;
 }
 
 static void
@@ -217,6 +270,9 @@ gda_data_model_array_get_type (void)
 
 /**
  * gda_data_model_array_new
+ * @cols: number of columns for rows in this data model.
+ *
+ * Returns: a pointer to the newly created #GdaDataModel.
  */
 GdaDataModel *
 gda_data_model_array_new (gint cols)
@@ -230,6 +286,11 @@ gda_data_model_array_new (gint cols)
 
 /**
  * gda_data_model_array_set_n_columns
+ * @model: the #GdaDataModelArray.
+ * @cols: number of columns for rows this data model should use.
+ *
+ * Sets the number of columns for rows inserted in this model. 
+ * @cols must be greated than or equal to 0.
  */
 void
 gda_data_model_array_set_n_columns (GdaDataModelArray *model, gint cols)
@@ -241,6 +302,9 @@ gda_data_model_array_set_n_columns (GdaDataModelArray *model, gint cols)
 
 /**
  * gda_data_model_array_clear
+ * @model: the model to clear.
+ *
+ * Frees all the rows inserted in @model.
  */
 void
 gda_data_model_array_clear (GdaDataModelArray *model)
