@@ -179,7 +179,7 @@ gda_mdb_provider_new (void)
 static const gchar *
 gda_mdb_provider_get_version (GdaServerProvider *provider)
 {
-	return VERSION;
+	return PACKAGE_VERSION;
 }
 
 /* open_connection handler for the GdaMdbProvider class */
@@ -389,7 +389,7 @@ gda_mdb_provider_execute_command (GdaServerProvider *provider,
 			g_strfreev (arr);
 		}
 		break;
-	default :
+	default : ;
 	}
 
 	return reclist;
@@ -438,7 +438,7 @@ gda_mdb_provider_supports (GdaServerProvider *provider,
 	case GDA_CONNECTION_FEATURE_PROCEDURES :
 	case GDA_CONNECTION_FEATURE_SQL :
 		return TRUE;
-	default :
+	default : ;
 	}
 
 	return FALSE;
@@ -738,6 +738,12 @@ gda_mdb_provider_execute_sql (GdaMdbProvider *mdbprv, GdaConnection *cnc, const
 		mdb_sql_reset (mdb_SQL);
 		return NULL;
 	}
+	if (!mdb_SQL->cur_table) {
+		/* parsing went fine, but there is no result
+		   (e.g. because of an invalid column name) */
+		gda_connection_add_error_string (cnc, _("Got no result for '%s' command"), sql);
+		return NULL;
+	}
 
 	model = gda_table_new (sql);
 
