@@ -404,7 +404,7 @@ static gboolean
 config_load_file (const gchar *file)
 {
 	gchar *file_contents;
-	gsize  len;
+	gint len;
 
 	if (g_file_get_contents (file, &file_contents, &len, NULL)){
 		config_data = parse_config_file (file_contents, len);
@@ -1378,12 +1378,12 @@ batch_options ()
 static void
 add_param_name_to_string (gpointer data, gpointer user_data)
 {
-	gchar *param = data;
+	GdaProviderParameterInfo *param_info = data;
 	GString *str = user_data;
 
-	if (param != NULL) {
+	if (param_info != NULL) {
 		g_string_append_c (str, ' ');
-		g_string_append (str, param);
+		g_string_append (str, param_info->name);
 	}
 }
 
